@@ -1,10 +1,10 @@
-__version__ = "0.0.1"
+__version__ = "0.0.2"
 __git_commiter_name__ = "Tal Yalon"
 __git_commiter_email__ = "yalon@infinidat.com"
-__git_branch__ = '(detached from v0.0.1)'
+__git_branch__ = '(detached from v0.0.2)'
 __git_remote_tracking_branch__ = '(No remote tracking)'
 __git_remote_url__ = '(Not remote tracking)'
-__git_head_hash__ = '20690cfb1ab73fc5f6ed53617192b9b312f9e9d9'
-__git_head_subject__ = 'Finished release v0.0.1.'
+__git_head_hash__ = '5d6d819b4a41ab8b8556b036501b580e19268b81'
+__git_head_subject__ = 'added install greeter on ubuntu'
 __git_head_message__ = ''
 __git_dirty_diff__ = ''
\ No newline at end of file
